@@ -394,7 +394,7 @@ cartesian2dGrob <- function(widget, interiorPlotGrob = NULL, name = NULL, gp = N
           ),
           # Axes
           gTree(children = gList(condGrob(test =  showScales,
-                                          grobFun = xaxisGrob,
+                                          grobFun = .xaxisGrob,
                                           name = "x axis",
                                           at = xaxis.major,
                                           gp = gpar(fontfamily = scalesFont$family,
@@ -402,7 +402,7 @@ cartesian2dGrob <- function(widget, interiorPlotGrob = NULL, name = NULL, gp = N
                                                     fontface = scalesFont$face
                                           )),
                                  condGrob(test =  showScales,
-                                          grobFun = yaxisGrob,
+                                          grobFun = .yaxisGrob,
                                           name = "y axis",
                                           at = yaxis.major,
                                           gp = gpar(fontfamily = scalesFont$family,
@@ -965,20 +965,6 @@ get_font_info_from_tk <- function(tkFont) {
   list(family = fontFamily, face = fontFace, size = fontSize)
 }
 
-as_hex6color <- function(color) {
-
-  if(length(color) > 0){
-    col <- vapply(color, function(x) {
-      if (x == "") "" else l_hexcolor(x)
-    }, character(1))
-    col <- suppressWarnings(hex12tohex6(col))
-    col[color == ""] <- NA
-    col
-  } else {
-    NA
-  }
-}
-
 
 
 
@@ -1325,7 +1311,7 @@ loon.pretty <- function(widget, digits = 3) {
 #' @export
 
 condGrob <- function (test = TRUE,
-                      grobFun = grob,
+                      grobFun = grid::grob,
                       name = "grob name",
                       ...){
   if (test){
@@ -1339,6 +1325,52 @@ condGrob <- function (test = TRUE,
   }
 }
 
+.xaxisGrob <- function(at = NULL, label = TRUE, main = TRUE,
+                       edits = NULL, name = NULL,
+                       gp = gpar(), vp = NULL) {
+
+  xaxis <- grid::xaxisGrob(at = at, label = label, main = main,
+                           edits = edits, name = name,
+                           gp = gp, vp = vp)
+
+  tryCatch(
+    {
+      # extract the name
+      major <- grid::getGrob(xaxis, "major")
+      # remove the major (remove the line at the base of the tick marks)
+      grid::setGrob(xaxis,
+                    "major",
+                    grid::nullGrob(name = major$name))
+    },
+    error = function(e) {
+      xaxis
+    }
+  )
+}
+
+.yaxisGrob <- function(at = NULL, label = TRUE, main = TRUE,
+                       edits = NULL, name = NULL,
+                       gp = gpar(), vp = NULL) {
+
+  yaxis <- grid::yaxisGrob(at = at, label = label, main = main,
+                           edits = edits, name = name,
+                           gp = gp, vp = vp)
+
+  tryCatch(
+    {
+      # extract the name
+      major <- grid::getGrob(yaxis, "major")
+      # remove the major (remove the line at the base of the tick marks)
+      grid::setGrob(yaxis,
+                    "major",
+                    grid::nullGrob(name = major$name))
+    },
+    error = function(e) {
+      yaxis
+    }
+  )
+}
+
 
 background_alpha <- function(x) {
   ifelse(x == "#999999999999", 0, 1)
